==> jscad__dxf-serializer-2.1.3.jar: META-INF/resources/webjars/jscad__dxf-serializer/2.1.3/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [2.1.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.1.2...@jscad/dxf-serializer@2.1.3) (2022-02-19)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.1.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.1.1...@jscad/dxf-serializer@2.1.2) (2021-12-26)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.1.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.1.0...@jscad/dxf-serializer@2.1.1) (2021-12-11)

**Note:** Version bump only for package @jscad/dxf-serializer





# [2.1.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.10...@jscad/dxf-serializer@2.1.0) (2021-11-07)


### Features

* **io:** new serializer for OBJ ([#942](https://github.com/jscad/OpenJSCAD.org/issues/942)) ([baaae18](https://github.com/jscad/OpenJSCAD.org/commit/baaae18ad55252ec71b074bd85dea7d137a22eb8))





## [2.0.10](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.9...@jscad/dxf-serializer@2.0.10) (2021-10-17)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.0.9](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.8...@jscad/dxf-serializer@2.0.9) (2021-10-04)


### Bug Fixes

* **dxf-serializer:** corrected selection of color palettes ([#925](https://github.com/jscad/OpenJSCAD.org/issues/925)) ([e73dab4](https://github.com/jscad/OpenJSCAD.org/commit/e73dab4116bd61fb46d0d44e5f4d39f68182cbdc))





## [2.0.8](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.7...@jscad/dxf-serializer@2.0.8) (2021-09-27)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.0.7](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.6...@jscad/dxf-serializer@2.0.7) (2021-09-09)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.0.6](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.5...@jscad/dxf-serializer@2.0.6) (2021-06-20)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.0.5](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.4...@jscad/dxf-serializer@2.0.5) (2021-06-11)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.0.4](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.3...@jscad/dxf-serializer@2.0.4) (2021-06-01)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.0.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.2...@jscad/dxf-serializer@2.0.3) (2021-04-20)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.0.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.0...@jscad/dxf-serializer@2.0.2) (2021-04-17)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))
* **dxf-deserializer:** support for colors in dxf serializer ([#684](https://github.com/jscad/OpenJSCAD.org/issues/684)) ([2b89a3a](https://github.com/jscad/OpenJSCAD.org/commit/2b89a3a7c4dde177ed93769d96522319954188df))
* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))
* **modeling:** V2 revisit modifiers ([#773](https://github.com/jscad/OpenJSCAD.org/issues/773)) ([1e28120](https://github.com/jscad/OpenJSCAD.org/commit/1e28120d2b8505dc1882cf3d607296d6fcd5526d))





## [2.0.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.0...@jscad/dxf-serializer@2.0.1) (2021-04-15)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))
* **dxf-deserializer:** support for colors in dxf serializer ([#684](https://github.com/jscad/OpenJSCAD.org/issues/684)) ([2b89a3a](https://github.com/jscad/OpenJSCAD.org/commit/2b89a3a7c4dde177ed93769d96522319954188df))
* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))
* **modeling:** V2 revisit modifiers ([#773](https://github.com/jscad/OpenJSCAD.org/issues/773)) ([1e28120](https://github.com/jscad/OpenJSCAD.org/commit/1e28120d2b8505dc1882cf3d607296d6fcd5526d))





# [2.0.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.11...@jscad/dxf-serializer@2.0.0) (2021-04-12)

**Note:** Version bump only for package @jscad/dxf-serializer





# [2.0.0-alpha.11](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.10...@jscad/dxf-serializer@2.0.0-alpha.11) (2021-03-07)


### Bug Fixes

* **modeling:** V2 revisit modifiers ([#773](https://github.com/jscad/OpenJSCAD.org/issues/773)) ([1e28120](https://github.com/jscad/OpenJSCAD.org/commit/1e28120d2b8505dc1882cf3d607296d6fcd5526d))





# [2.0.0-alpha.10](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.9...@jscad/dxf-serializer@2.0.0-alpha.10) (2021-02-07)

**Note:** Version bump only for package @jscad/dxf-serializer





# [2.0.0-alpha.9](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.8...@jscad/dxf-serializer@2.0.0-alpha.9) (2021-01-02)

**Note:** Version bump only for package @jscad/dxf-serializer





# [2.0.0-alpha.8](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.7...@jscad/dxf-serializer@2.0.0-alpha.8) (2020-12-04)

**Note:** Version bump only for package @jscad/dxf-serializer





# [2.0.0-alpha.7](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.6...@jscad/dxf-serializer@2.0.0-alpha.7) (2020-11-07)


### Bug Fixes

* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))





# [2.0.0-alpha.6](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.5...@jscad/dxf-serializer@2.0.0-alpha.6) (2020-10-11)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))





# [2.0.0-alpha.5](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.4...@jscad/dxf-serializer@2.0.0-alpha.5) (2020-09-29)

**Note:** Version bump only for package @jscad/dxf-serializer





# [2.0.0-alpha.4](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.3...@jscad/dxf-serializer@2.0.0-alpha.4) (2020-09-28)

**Note:** Version bump only for package @jscad/dxf-serializer





# [2.0.0-alpha.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.2...@jscad/dxf-serializer@2.0.0-alpha.3) (2020-09-19)


### Bug Fixes

* **dxf-deserializer:** support for colors in dxf serializer ([#684](https://github.com/jscad/OpenJSCAD.org/issues/684)) ([2b89a3a](https://github.com/jscad/OpenJSCAD.org/commit/2b89a3a7c4dde177ed93769d96522319954188df))





# [2.0.0-alpha.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.1...@jscad/dxf-serializer@2.0.0-alpha.2) (2020-09-08)

**Note:** Version bump only for package @jscad/dxf-serializer





# [2.0.0-alpha.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.0...@jscad/dxf-serializer@2.0.0-alpha.1) (2020-08-19)

**Note:** Version bump only for package @jscad/dxf-serializer





# 2.0.0-alpha.0 (2020-08-13)


### Bug Fixes

* **dxf-serializer:** removed unnecessary 2D entities from BLOCKS section ([#537](https://github.com/jscad/OpenJSCAD.org/issues/537)) ([21a6d38](https://github.com/jscad/OpenJSCAD.org/commit/21a6d38a62a7fed353bdb3fc5e834178cac7b239))





### Features

* **dxf-serializer:** updated for V2 (#474)


<a name="0.3.0"></a>
# [0.3.0](https://github.com/jscad/io/compare/@jscad/dxf-serializer@0.2.5...@jscad/dxf-serializer@0.3.0) (2018-11-25)

<a name="0.2.5"></a>
## [0.2.5](https://github.com/jscad/io/compare/@jscad/dxf-serializer@0.2.4...@jscad/dxf-serializer@0.2.5) (2018-11-22)


**Note:** Version bump only for package @jscad/dxf-serializer

<a name="0.2.4"></a>
## [0.2.4](https://github.com/jscad/io/compare/@jscad/dxf-serializer@0.2.3...@jscad/dxf-serializer@0.2.4) (2018-09-02)




**Note:** Version bump only for package @jscad/dxf-serializer

<a name="0.2.3"></a>
## [0.2.3](https://github.com/jscad/io/compare/@jscad/dxf-serializer@0.2.2...@jscad/dxf-serializer@0.2.3) (2018-06-11)


### Bug Fixes

* **dxf-serializer:** corrected polygonToTriangles when polygon has less then 3 vertices ([#68](https://github.com/jscad/io/issues/68)) ([accac07](https://github.com/jscad/io/commit/accac07))




<a name="0.2.2"></a>
## [0.2.2](https://github.com/jscad/io/compare/@jscad/dxf-serializer@0.2.1...@jscad/dxf-serializer@0.2.2) (2018-05-24)


### Bug Fixes

* **dxf-serializer:** fix 3d faces output ([#67](https://github.com/jscad/io/issues/67)) ([51d316e](https://github.com/jscad/io/commit/51d316e))




<a name="0.2.1"></a>
## [0.2.1](https://github.com/jscad/io/compare/@jscad/dxf-serializer@0.2.0...@jscad/dxf-serializer@0.2.1) (2018-04-07)


### Bug Fixes

* **dxf-serializer:** Corrected EOF group as well as test cases ([#61](https://github.com/jscad/io/issues/61)) ([760c350](https://github.com/jscad/io/commit/760c350))
* **dxf-serializer:** Removed extra line after ENDSEC which caused format errors in DXF ([#62](https://github.com/jscad/io/issues/62)) ([c967c4b](https://github.com/jscad/io/commit/c967c4b))




<a name="0.2.0"></a>
# [0.2.0](https://github.com/jscad/io/compare/@jscad/dxf-serializer@0.1.2...@jscad/dxf-serializer@0.2.0) (2018-04-01)


### Features

* **dxf-serializer:** DXF Serializer updates ([#59](https://github.com/jscad/io/issues/59)) ([68c0d30](https://github.com/jscad/io/commit/68c0d30))




<a name="0.1.2"></a>
## [0.1.2](https://github.com/jscad/io/compare/@jscad/dxf-serializer@0.1.1...@jscad/dxf-serializer@0.1.2) (2017-12-14)




**Note:** Version bump only for package @jscad/dxf-serializer

<a name="0.1.1"></a>
## [0.1.1](https://github.com/jscad/io/compare/@jscad/dxf-serializer@0.1.0...@jscad/dxf-serializer@0.1.1) (2017-12-14)




**Note:** Version bump only for package @jscad/dxf-serializer

<a name="0.1.0"></a>
# [0.1.0](https://github.com/jscad/io/compare/@jscad/dxf-serializer@0.0.4...@jscad/dxf-serializer@0.1.0) (2017-11-29)


### Features

* add support for a status callback for de/serialization progress ([#49](https://github.com/jscad/io/issues/49)) ([f457cdb](https://github.com/jscad/io/commit/f457cdb))




<a name="0.0.4"></a>
## [0.0.4](https://github.com/jscad/io/compare/@jscad/dxf-serializer@0.0.3...@jscad/dxf-serializer@0.0.4) (2017-11-04)




**Note:** Version bump only for package @jscad/dxf-serializer

<a name="0.0.3"></a>
## [0.0.3](https://github.com/jscad/io/compare/@jscad/dxf-serializer@0.0.2...@jscad/dxf-serializer@0.0.3) (2017-10-10)




**Note:** Version bump only for package @jscad/dxf-serializer

<a name="0.0.2"></a>
## 0.0.2 (2017-10-10)




**Note:** Version bump only for package @jscad/dxf-serializer

==> jscad__dxf-serializer-2.1.13.jar: META-INF/resources/webjars/jscad__dxf-serializer/2.1.13/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [2.1.13](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.1.12...@jscad/dxf-serializer@2.1.13) (2022-11-26)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.1.12](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.1.11...@jscad/dxf-serializer@2.1.12) (2022-08-21)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.1.11](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.1.10...@jscad/dxf-serializer@2.1.11) (2022-07-17)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.1.10](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.1.9...@jscad/dxf-serializer@2.1.10) (2022-06-12)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.1.9](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.1.8...@jscad/dxf-serializer@2.1.9) (2022-05-15)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.1.8](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.1.7...@jscad/dxf-serializer@2.1.8) (2022-04-24)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.1.7](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.1.6...@jscad/dxf-serializer@2.1.7) (2022-04-03)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.1.6](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.1.5...@jscad/dxf-serializer@2.1.6) (2022-04-03)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.1.5](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.1.4...@jscad/dxf-serializer@2.1.5) (2022-03-13)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.1.4](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.1.3...@jscad/dxf-serializer@2.1.4) (2022-03-06)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.1.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.1.2...@jscad/dxf-serializer@2.1.3) (2022-02-19)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.1.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.1.1...@jscad/dxf-serializer@2.1.2) (2021-12-26)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.1.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.1.0...@jscad/dxf-serializer@2.1.1) (2021-12-11)

**Note:** Version bump only for package @jscad/dxf-serializer





# [2.1.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.10...@jscad/dxf-serializer@2.1.0) (2021-11-07)


### Features

* **io:** new serializer for OBJ ([#942](https://github.com/jscad/OpenJSCAD.org/issues/942)) ([baaae18](https://github.com/jscad/OpenJSCAD.org/commit/baaae18ad55252ec71b074bd85dea7d137a22eb8))





## [2.0.10](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.9...@jscad/dxf-serializer@2.0.10) (2021-10-17)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.0.9](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.8...@jscad/dxf-serializer@2.0.9) (2021-10-04)


### Bug Fixes

* **dxf-serializer:** corrected selection of color palettes ([#925](https://github.com/jscad/OpenJSCAD.org/issues/925)) ([e73dab4](https://github.com/jscad/OpenJSCAD.org/commit/e73dab4116bd61fb46d0d44e5f4d39f68182cbdc))





## [2.0.8](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.7...@jscad/dxf-serializer@2.0.8) (2021-09-27)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.0.7](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.6...@jscad/dxf-serializer@2.0.7) (2021-09-09)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.0.6](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.5...@jscad/dxf-serializer@2.0.6) (2021-06-20)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.0.5](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.4...@jscad/dxf-serializer@2.0.5) (2021-06-11)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.0.4](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.3...@jscad/dxf-serializer@2.0.4) (2021-06-01)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.0.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.2...@jscad/dxf-serializer@2.0.3) (2021-04-20)

**Note:** Version bump only for package @jscad/dxf-serializer





## [2.0.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.0...@jscad/dxf-serializer@2.0.2) (2021-04-17)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))
* **dxf-deserializer:** support for colors in dxf serializer ([#684](https://github.com/jscad/OpenJSCAD.org/issues/684)) ([2b89a3a](https://github.com/jscad/OpenJSCAD.org/commit/2b89a3a7c4dde177ed93769d96522319954188df))
* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))
* **modeling:** V2 revisit modifiers ([#773](https://github.com/jscad/OpenJSCAD.org/issues/773)) ([1e28120](https://github.com/jscad/OpenJSCAD.org/commit/1e28120d2b8505dc1882cf3d607296d6fcd5526d))





## [2.0.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.0...@jscad/dxf-serializer@2.0.1) (2021-04-15)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))
* **dxf-deserializer:** support for colors in dxf serializer ([#684](https://github.com/jscad/OpenJSCAD.org/issues/684)) ([2b89a3a](https://github.com/jscad/OpenJSCAD.org/commit/2b89a3a7c4dde177ed93769d96522319954188df))
* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))
* **modeling:** V2 revisit modifiers ([#773](https://github.com/jscad/OpenJSCAD.org/issues/773)) ([1e28120](https://github.com/jscad/OpenJSCAD.org/commit/1e28120d2b8505dc1882cf3d607296d6fcd5526d))





# [2.0.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.11...@jscad/dxf-serializer@2.0.0) (2021-04-12)

**Note:** Version bump only for package @jscad/dxf-serializer





# [2.0.0-alpha.11](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.10...@jscad/dxf-serializer@2.0.0-alpha.11) (2021-03-07)


### Bug Fixes

* **modeling:** V2 revisit modifiers ([#773](https://github.com/jscad/OpenJSCAD.org/issues/773)) ([1e28120](https://github.com/jscad/OpenJSCAD.org/commit/1e28120d2b8505dc1882cf3d607296d6fcd5526d))





# [2.0.0-alpha.10](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.9...@jscad/dxf-serializer@2.0.0-alpha.10) (2021-02-07)

**Note:** Version bump only for package @jscad/dxf-serializer





# [2.0.0-alpha.9](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.8...@jscad/dxf-serializer@2.0.0-alpha.9) (2021-01-02)

**Note:** Version bump only for package @jscad/dxf-serializer





# [2.0.0-alpha.8](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.7...@jscad/dxf-serializer@2.0.0-alpha.8) (2020-12-04)

**Note:** Version bump only for package @jscad/dxf-serializer





# [2.0.0-alpha.7](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.6...@jscad/dxf-serializer@2.0.0-alpha.7) (2020-11-07)


### Bug Fixes

* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))





# [2.0.0-alpha.6](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.5...@jscad/dxf-serializer@2.0.0-alpha.6) (2020-10-11)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))





# [2.0.0-alpha.5](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.4...@jscad/dxf-serializer@2.0.0-alpha.5) (2020-09-29)

**Note:** Version bump only for package @jscad/dxf-serializer





# [2.0.0-alpha.4](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.3...@jscad/dxf-serializer@2.0.0-alpha.4) (2020-09-28)

**Note:** Version bump only for package @jscad/dxf-serializer





# [2.0.0-alpha.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.2...@jscad/dxf-serializer@2.0.0-alpha.3) (2020-09-19)


### Bug Fixes

* **dxf-deserializer:** support for colors in dxf serializer ([#684](https://github.com/jscad/OpenJSCAD.org/issues/684)) ([2b89a3a](https://github.com/jscad/OpenJSCAD.org/commit/2b89a3a7c4dde177ed93769d96522319954188df))





# [2.0.0-alpha.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.1...@jscad/dxf-serializer@2.0.0-alpha.2) (2020-09-08)

**Note:** Version bump only for package @jscad/dxf-serializer





# [2.0.0-alpha.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/dxf-serializer@2.0.0-alpha.0...@jscad/dxf-serializer@2.0.0-alpha.1) (2020-08-19)

**Note:** Version bump only for package @jscad/dxf-serializer





# 2.0.0-alpha.0 (2020-08-13)


### Bug Fixes

* **dxf-serializer:** removed unnecessary 2D entities from BLOCKS section ([#537](https://github.com/jscad/OpenJSCAD.org/issues/537)) ([21a6d38](https://github.com/jscad/OpenJSCAD.org/commit/21a6d38a62a7fed353bdb3fc5e834178cac7b239))





### Features

* **dxf-serializer:** updated for V2 (#474)


<a name="0.3.0"></a>
# [0.3.0](https://github.com/jscad/io/compare/@jscad/dxf-serializer@0.2.5...@jscad/dxf-serializer@0.3.0) (2018-11-25)

<a name="0.2.5"></a>
## [0.2.5](https://github.com/jscad/io/compare/@jscad/dxf-serializer@0.2.4...@jscad/dxf-serializer@0.2.5) (2018-11-22)


**Note:** Version bump only for package @jscad/dxf-serializer

<a name="0.2.4"></a>
## [0.2.4](https://github.com/jscad/io/compare/@jscad/dxf-serializer@0.2.3...@jscad/dxf-serializer@0.2.4) (2018-09-02)




**Note:** Version bump only for package @jscad/dxf-serializer

<a name="0.2.3"></a>
## [0.2.3](https://github.com/jscad/io/compare/@jscad/dxf-serializer@0.2.2...@jscad/dxf-serializer@0.2.3) (2018-06-11)


### Bug Fixes

* **dxf-serializer:** corrected polygonToTriangles when polygon has less then 3 vertices ([#68](https://github.com/jscad/io/issues/68)) ([accac07](https://github.com/jscad/io/commit/accac07))




<a name="0.2.2"></a>
## [0.2.2](https://github.com/jscad/io/compare/@jscad/dxf-serializer@0.2.1...@jscad/dxf-serializer@0.2.2) (2018-05-24)


### Bug Fixes

* **dxf-serializer:** fix 3d faces output ([#67](https://github.com/jscad/io/issues/67)) ([51d316e](https://github.com/jscad/io/commit/51d316e))




<a name="0.2.1"></a>
## [0.2.1](https://github.com/jscad/io/compare/@jscad/dxf-serializer@0.2.0...@jscad/dxf-serializer@0.2.1) (2018-04-07)


### Bug Fixes

* **dxf-serializer:** Corrected EOF group as well as test cases ([#61](https://github.com/jscad/io/issues/61)) ([760c350](https://github.com/jscad/io/commit/760c350))
* **dxf-serializer:** Removed extra line after ENDSEC which caused format errors in DXF ([#62](https://github.com/jscad/io/issues/62)) ([c967c4b](https://github.com/jscad/io/commit/c967c4b))




<a name="0.2.0"></a>
# [0.2.0](https://github.com/jscad/io/compare/@jscad/dxf-serializer@0.1.2...@jscad/dxf-serializer@0.2.0) (2018-04-01)


### Features

* **dxf-serializer:** DXF Serializer updates ([#59](https://github.com/jscad/io/issues/59)) ([68c0d30](https://github.com/jscad/io/commit/68c0d30))




<a name="0.1.2"></a>
## [0.1.2](https://github.com/jscad/io/compare/@jscad/dxf-serializer@0.1.1...@jscad/dxf-serializer@0.1.2) (2017-12-14)




**Note:** Version bump only for package @jscad/dxf-serializer

<a name="0.1.1"></a>
## [0.1.1](https://github.com/jscad/io/compare/@jscad/dxf-serializer@0.1.0...@jscad/dxf-serializer@0.1.1) (2017-12-14)




**Note:** Version bump only for package @jscad/dxf-serializer

<a name="0.1.0"></a>
# [0.1.0](https://github.com/jscad/io/compare/@jscad/dxf-serializer@0.0.4...@jscad/dxf-serializer@0.1.0) (2017-11-29)


### Features

* add support for a status callback for de/serialization progress ([#49](https://github.com/jscad/io/issues/49)) ([f457cdb](https://github.com/jscad/io/commit/f457cdb))




<a name="0.0.4"></a>
## [0.0.4](https://github.com/jscad/io/compare/@jscad/dxf-serializer@0.0.3...@jscad/dxf-serializer@0.0.4) (2017-11-04)




**Note:** Version bump only for package @jscad/dxf-serializer

<a name="0.0.3"></a>
## [0.0.3](https://github.com/jscad/io/compare/@jscad/dxf-serializer@0.0.2...@jscad/dxf-serializer@0.0.3) (2017-10-10)




**Note:** Version bump only for package @jscad/dxf-serializer

<a name="0.0.2"></a>
## 0.0.2 (2017-10-10)




**Note:** Version bump only for package @jscad/dxf-serializer
